# Generated by Django 4.2 on 2023-12-02 03:20

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('advance', '0006_delete_javascript'),
    ]

    operations = [
        migrations.CreateModel(
            name='admin_update',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=100)),
                ('url', models.URLField(default='bigsansar.com/dashboard')),
                ('publish_date', models.DateField(auto_now_add=True)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'update',
                'verbose_name_plural': 'Admin Update',
            },
        ),
    ]



import argparse
from bigsansar.core.init import deploy, initsetup


class root:

    def __init__(self):
        self.parser = argparse.ArgumentParser()
        self.parser.add_argument('init', help='Create a django server and related files ')
        self.parser.add_argument('server', help=' this is a base in to linux ubuntu. careate a server in to deploy side . ')

        self.args = self.parser.parse_args()

    def execute(self):

        if self.args.init == 'init':

            return initsetup()
        
        elif self.args.init.server == 'server':
            return deploy()
    
        else:
            print('usage: bigsansar --help')
            exit()

def main():
   cli = root()
   cli.execute()



from django.apps import AppConfig


class AdvanceConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'bigsansar.contrib.advance'
    verbose_name = 'Advance Function'



from django.urls import path

from bigsansar.contrib.sites import views



urlpatterns = [
    path('manage/<id>', views.manage_domain, name='manage doamin'),
    path('create', views.create_domain, name='create domain'),
    path('manage/<id>/edit', views.edit_host, name='edit domain'),
    path('manage/<id>/pages/create', views.page_create, name='pages add'),
    path('manage/<id>/pages/<pagesid>/edit', views.pages_edit, name='pages edit panel'),
    path('manage/<id>/pages/<pagesid>/delete', views.page_delete, name='page delete'),
 ]


# Generated by Django 4.2 on 2023-06-25 11:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('advance', '0005_delete_css'),
    ]

    operations = [
        migrations.DeleteModel(
            name='javascript',
        ),
    ]



from django import forms
from django.contrib.auth.forms import AuthenticationForm, PasswordResetForm, SetPasswordForm, UserCreationForm, UserChangeForm, PasswordChangeForm
from django.core.validators import RegexValidator
from django.contrib.auth.models import User
from phonenumber_field.formfields import PhoneNumberField
from bigsansar.contrib.advance.models import admin_update
from bigsansar.contrib.account.models import userinfo


class loginform(AuthenticationForm):
    username = forms.CharField(max_length=50, widget=forms.TextInput(attrs={'autofocus': True,'class': 'form-control', 'placeholder': 'Username'}))
    password = forms.CharField(widget=forms.PasswordInput(attrs={'class': 'form-control', 'placeholder': 'Password'}))


class userchform(UserChangeForm):
    password = None
    username = forms.CharField(max_length=50, validators=[
        RegexValidator('^[a-z0-9]+$', message='use Letters and digits with minimum of 3 character')], min_length=3,
                               help_text='use Letters and digits with minimum of 3 character',
                               widget=forms.TextInput(attrs={'autofocus': True,'class': 'form-control'}))

    class Meta:

        model = User
        fields = ['username']


class chpassform(PasswordChangeForm):
    old_password = forms.CharField(label='Old Password',
                                   widget=forms.PasswordInput(attrs={'autofocus': True, 'class': 'form-control'}))
    new_password1 = forms.CharField(label='New Password',
                                    widget=forms.PasswordInput(attrs={'class': 'form-control'}))
    new_password2 = forms.CharField(label='New Password confirmation',
                                    widget=forms.PasswordInput(attrs={'class': 'form-control'}))

    class Meta:
        model = User
        fields = ['password1', 'password2']


class profileform(UserChangeForm):
    first_name = forms.CharField(max_length=15, min_length=5, validators=[
        RegexValidator('^[A-Za-z]+$', message='Please enter your correct First name')],
                                 widget=forms.TextInput(attrs={'autofocus': True, 'class': 'form-control', }))
    last_name = forms.CharField(max_length=15, min_length=5, validators=[
        RegexValidator('^[A-Za-z]+$', message='Please enter your correct Last name')],
                                widget=forms.TextInput(attrs={'class': 'form-control', }))
    email = forms.EmailField(max_length=60, min_length=5, help_text='Required. Inform a valid email address.',
                             widget=forms.TextInput(attrs={'class': 'form-control'}))
    password = None

    class Meta:
        model = User
        fields = ('first_name', 'last_name', 'email',)



class usrinfoform(forms.ModelForm):
    phone = PhoneNumberField(required=False, widget=forms.TextInput(attrs={'class': 'form-control', }))
    address = forms.CharField(required=False, widget=forms.TextInput(attrs={'class': 'form-control', }))

    class Meta:
        model = userinfo
        fields = ('phone', 'address',)



class custom_admin_upadte(forms.ModelForm):
    title = forms.CharField(widget=forms.TextInput(attrs={'autofocus': True, 'class': 'form-control', }))
    url = forms.URLField(required=False, widget=forms.TextInput(attrs={'class': 'form-control', }))

    class Meta:
        model = admin_update
        fields = ('title', 'url',)


import json
import os
from django.shortcuts import redirect, render
from django.core.paginator import Paginator
import requests
from bigsansar.contrib.advance.models import admin_update
from bigsansar.contrib.sites.forms import create_domainform, customviewseditpage, customviewspageform
from django.contrib import messages
from bigsansar.contrib.sites.models import domains, pages
from django.utils.text import slugify
from django.core.exceptions import ValidationError

from www.settings import BASE_DIR

# Create your views here.


def manage_domain(request, id):
    if request.user.is_authenticated:

        try:
            ruser = request.user
            query = domains.objects.get(id=id, user=ruser)

        except:

            return render(request, '404.html')

        else:
            status = query.visitor
            if status == 0:
                visitor = 'Deactive'

            else:
                visitor = 'Active'

            getpage = pages.objects.filter(domain=id).order_by('-id')
            paginator = Paginator(getpage, 5)
            page_number = request.GET.get('page')
            page = paginator.get_page(page_number)
            ip = request.META.get('REMOTE_ADDR')
            res = requests.get('http://ip-api.com/json/' + ip)
            location_data_one = res.text
            geo = json.loads(location_data_one)
            browser = request.META['HTTP_USER_AGENT']
            update = admin_update.objects.all().order_by('-id')[:5]
            return render(request, 'admin/domain_manage.html', {'visitcount': status, 'count': visitor, 'host': query,
                                                          'pages': page, 'ip': ip, 'geo': geo, 'browser': browser,
                                                          'blog': update})
    else:
        return redirect('/admin')
    


def edit_host(request, id):

    if request.user.is_authenticated:

        try:
            user = request.user
            query = domains.objects.get(id=id, user=user)

        except:
            return render(request, '404.html')

        else:
            if request.method == 'POST':
                form = create_domainform(request.POST, instance=query)
                if form.is_valid():
                    form.save()
                    messages.success(request, 'Domain Successfully Updated')
                    return redirect('/admin/domain/manage/' + id)
            else:
                form = create_domainform(instance=query)
            return render(request, 'admin/edit_domain.html', {'form': form})

    else:
        return redirect('/login')



def page_create(request, id):
    if request.user.is_authenticated:
        try:
            user = request.user
            get_host = domains.objects.get(pk=id, user=user)

        except:
            return render(request, '404.html')

        getdir = 'templates'
        if request.method == 'POST':
            form = customviewspageform(request.POST)
            if form.is_valid():

                if pages.objects.filter(slug=slugify(form.cleaned_data.get('title')), domain=get_host):
                    messages.warning(request, 'page with url' + ' ' + slugify(
                        form.cleaned_data.get('title')) + ' ' + 'already exists for domain' + ' ' + get_host.domain)
                    form = customviewspageform
                    return render(request, 'admin/page_create.html', {'form': form})

                query = form.save(commit=False)
                query.domain = get_host
                query.slug = slugify(form.cleaned_data.get('title'))
                mkdir = getdir + '/' + str(get_host.domain)

                try:
                    final_directory = os.path.join(BASE_DIR, mkdir)
                    if not os.path.exists(final_directory):
                        os.makedirs(final_directory)
                except:
                    raise ValidationError(
                        _(final_directory + ' Directory not created "Permission Denied"'),
                    )

                query.save()

                messages.success(request, 'Pages Successfully Created')
                return redirect('/admin/domain/manage/' + id)

        else:
            form = customviewspageform
        return render(request, 'admin/page_create.html', {'form': form})

    else:
        return redirect('/admin')



def pages_edit(request, id, pagesid):
    if request.user.is_authenticated:
        getdir = 'templates'

        try:
            user = request.user
            get_host = domains.objects.get(pk=id, user=user)
            query = pages.objects.get(domain=id, id=pagesid)

        except:
            return render(request, '404.html')

        else:
            if request.method == 'POST':
                form = customviewseditpage(request.POST, instance=query)
                if form.is_valid():
                    db = form.save(commit=False)
                    db.domain = get_host

                    mkdir = getdir + '/' + str(get_host.domain)
                    full_path = os.path.join(BASE_DIR, mkdir)
                    createfile = full_path + '/' + query.slug + '.html'
                    get_content = form.cleaned_data.get('body')

                    f = open(createfile, "w", encoding="utf-8")
                    f.write(get_content)
                    f.close()
                    db.save()
                    messages.success(request, 'pages Successfully Updated')
                    return redirect('/admin/domain/manage/' + id)

            else:
                form = customviewseditpage(instance=query)

            return render(request, 'admin/page_edit.html', {'form': form})

    else:

        return redirect('/admin')



def page_delete(request, id, pagesid):
    if request.user.is_authenticated:
        getdir = 'templates'

        try:
            user = request.user
            getdomain = domains.objects.get(pk=id, user=user)
            query = pages.objects.get(domain=id, id=pagesid)

        except:
            return render(request, '404.html')

        if request.method == 'POST':
            mkdir = getdir + '/' + str(getdomain.domain)
            createfile = mkdir + '/' + query.slug + '.html'

            if os.path.exists(createfile):
                os.remove(createfile)
                query.delete()
            else:
                query.delete()

            messages.success(request, 'Pages Successfully Deleted')
            return redirect('/admin/domain/manage/' + id)
        return render(request, 'admin/page_delete.html', {'path': query, 'domain': getdomain})

    else:
        redirect('/admin')


# Create your views here.
def create_domain(request):
    if request.user.is_authenticated:
        if request.user.is_superuser:

            if request.method == 'POST':
                form = create_domainform(request.POST)

                if form.is_valid():
                    query = form.save(commit=False)
                    query.user = request.user
                    query.save()
                    messages.success(request, 'domain Successfully Created')
                    return redirect('/admin/dashboard')

            else:
                form = create_domainform()
            return render(request, 'admin/create_domain.html', {'form': form})

        else:
            return render(request, '404.html')
    else:
        return redirect('/admin')